#!/bin/sh
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi

# build order is libfm-extra-dev menu-cache libfm pcmanfm
export CFLAGS="-mtune=generic -Os -pipe"
export CXXFLAGS="-mtune=generic -Os -pipe -fno-exceptions -fno-rtti"

P=menu-cache
V=1.1.0
SRC=$P-$V
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc submitqc libfm-extra-dev "
for Z in $LIST
    do 
    su -c "tce-load -i $Z" $USER
done

LFS=http://www.linuxfromscratch.org/patches/blfs/svn
cd /tmp
su -c "/usr/local/bin/wget -nc --no-check-certificate \
https://sourceforge.net/projects/lxde/files/$P/1.1/$SRC.tar.xz \
$LFS/menu-cache-1.1.0-consolidated_fixes-1.patch  "  $USER
xz -d $P*xz && tar xvf $P*tar
cd $SRC
patch -Np1 -i ../menu-cache-1.1.0-consolidated_fixes-1.patch

./configure --prefix=/usr/local --disable-static --enable-debug=no
make check # takes seconds
make install-strip DESTDIR=/tmp/$P
cd /tmp

# dev
#####
mkdir -p $P-dev/usr/local/lib/
mv $P/usr/local/include $P-dev/usr/local/
mv $P/usr/local/lib/pkgconfig $P-dev/usr/local/lib/
mv $P/usr/local/lib/*a $P-dev/usr/local/lib/
chmod 644 $P-dev/usr/local/lib/*a 

# main
#######
mkdir -p $P/usr/local/share/doc/$P
echo 'LGPL v2.1' > $P/usr/local/share/doc/$P/COPYING

# TCZ them
###########
LIST="$P $P-dev  "
for Z in $LIST
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'Title:          menu-cache-dev.tcz
Description:    dev files
Version:        1.1.0
Author:         https://github.com/lxde/menu-cache/blob/master/AUTHORS
                patch author=Pierre Labastie
Original-site:  https://sourceforge.net/projects/lxde/files/menu-cache/
Copying-policy: LGPL v2.1
Size:           4.0K
Extension_by:   aus9
Tags:           menu-cache
Comments:       Dev files
                
Change-log:     2014/01/18 First version, 0.5.0 (bmarkus)
                2015/08/20 v 0.7.0  (gordon64)
                2019/02/11 v 1.1.0 on 10x (aus9) 
                2020/07/18 rebuilt for 11x 
Current:        2023/03/20 14x for updated libfm-extra-dev  ' > $P-dev.tcz.info

echo 'Title:          menu-cache.tcz
Description:    menu cache Library 
Version:        1.1.0
Author:         see https://github.com/lxde/menu-cache/blob/master/AUTHORS
Original-site:  https://sourceforge.net/projects/lxde/files/menu-cache/
Copying-policy: LGPL v2.1
Size:           44K
Extension_by:   AUS9
Tags:           menu-cache      
Comments:       A library to speed up the manipulation 
                for freedesktop.org defined application menus
                recursive dep of pcmanfm

Change-log:     2014/01/18 First version, 0.5.0 (bmarkus)
                2015/08/20 v 0.7.0  (gordon64)
                2019/02/11 v 1.1.0 on 10x (aus9) 
                2020/07/18 rebuilt for 11x 
Current:        2023/03/20 14x for updated libfm-extra-dev ' > $P.tcz.info

readelf -d $P/usr/local//lib/libmenu-cache.so | grep 'NEEDED'
###############################################
# 0x0000000000000001 (NEEDED) Shared library: [libgio-2.0.so.0] glib2
# 0x0000000000000001 (NEEDED) Shared library: [libgobject-2.0.so.0] "
# 0x0000000000000001 (NEEDED) Shared library: [libglib-2.0.so.0]   "
# 0x0000000000000001 (NEEDED) Shared library: [libc.so.6] TCB
###############################################


echo 'menu-cache.tcz
libfm-extra-dev.tcz  '> $P-dev.tcz.dep

echo 'glib2-dev.tcz '> $P.tcz.dep

submitqc --libs
